# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulpcore.models.pulp_export_response import PulpExportResponse

class TestPulpExportResponse(unittest.TestCase):
    """PulpExportResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PulpExportResponse:
        """Test PulpExportResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PulpExportResponse`
        """
        model = PulpExportResponse()
        if include_optional:
            return PulpExportResponse(
                pulp_href = '',
                prn = '',
                pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                task = '',
                exported_resources = [
                    ''
                    ],
                params = pulpcore.client.pulpcore.models.params.params(),
                output_file_info = pulpcore.client.pulpcore.models.output_file_info.output_file_info(),
                toc_info = pulpcore.client.pulpcore.models.toc_info.toc_info()
            )
        else:
            return PulpExportResponse(
        )
        """

    def testPulpExportResponse(self):
        """Test PulpExportResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
